@@ -17,7 +17,7 @@ use App::Memcached::CLI::Help;
 use App::Memcached::CLI::Item;
 use App::Memcached::CLI::Util ':all';
 
-use version; our $VERSION = 'v0.9.0';
+use version; our $VERSION = 'v0.9.1';
 
 my $PROGRAM = basename $0;
 
@@ -145,6 +145,11 @@ sub run_interactive {
             $exit_loop = 1;
             next;
         }
+        unless ($self->{ds}->ping) {
+            print "Server has gone away.\n";
+            $exit_loop = 1;
+            next;
+        }
 
         my $ret = $self->$command(@args);
         unless ($ret) {
